<?php

class SettingsController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array(''),
				'users'=>array('*'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array(''),
				'users'=>array('@'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('admin','delete','newTrimPhase','newTrimPhaseShort','create','update','simpleUpdate','simpleUpdateShort','index','view','clearNewTriDB', 'moveNewOver'),
				'users'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		$this->render('view',array(
			'model'=>$this->loadModel($id),
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new Settings;

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Settings']))
		{
			$model->attributes=$_POST['Settings'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->ID));
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Settings']))
		{
			$model->attributes=$_POST['Settings'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->ID));
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		$dataProvider=new CActiveDataProvider('Settings');
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new Settings('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['Settings']))
			$model->attributes=$_GET['Settings'];

		$this->render('admin',array(
			'model'=>$model,
		));
	}

        public function actionNewTrimPhase(){
            $this->layout='//layouts/column1';
            //if isset somedata -> change settings accordingly{}
            $set = Settings::model()->findAllByAttributes(array(
                'type'=>array(
                    'register_allowed', 
//                    'parent_choice', 
                    'new_trim_allowed',
                    'new_trim_timetable_change',
                    'save_new_register_to_newenlist',
                    )
                )
            );
            if(isset($_POST['something'])){
//              ulozit zmeny    
            }
            $this->render('newTrimPhase', array('set'=>$set));
            //RESET all trimester related settings
        }
        
        public function actionNewTrimPhaseShort(){
            $this->layout='//layouts/column1';
            //if isset somedata -> change settings accordingly{}
            $set = Settings::model()->findAllByAttributes(array(
                'type'=>array(
                    'register_allowed', 
//                    'parent_choice', 
                    'new_trim_allowed',
                    'new_trim_timetable_change_short',
                    'save_new_register_to_newenlist',
                    )
                )
            );
            if(isset($_POST['something'])){
//              ulozit zmeny    
            }
            $this->render('newTrimPhaseShort', array('set'=>$set));
            //RESET all trimester related settings
        }
        
        public function actionSimpleUpdate($id){
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Settings']))
		{
			$model->attributes=$_POST['Settings'];
			if($model->save())
				$this->redirect(array('newTrimPhase'));
		}

		$this->render('simpleUpdate',array(
			'model'=>$model,
		));
        }

        public function actionSimpleUpdateShort($id){
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Settings']))
		{
			$model->attributes=$_POST['Settings'];
			if($model->save())
				$this->redirect(array('newTrimPhaseShort'));
		}

		$this->render('simpleUpdate',array(
			'model'=>$model,
		));
        }        
        
        public function actionMoveNewOver(){
            //move newtimetable over timetable and move newelists over enlists
            Yii::app()->db->createCommand()->truncateTable('enlist');
            Yii::app()->db->createCommand()->truncateTable('timetable');
            
            $movett = Newtimetable::model()->findAll();
            $moveenl = Newenlist::model()->findAll();
            
            foreach ($movett as $single) {
                $tt = new Timetable('copy');
                $tt->setAttributes($single->getAttributes(), false); 
                $tt->save();
            }
            
            foreach ($moveenl as $single) {
                $enl = new Enlist('copy');
                $enl->setAttributes($single->getAttributes(), false); 
                $enl->save();
            }
            
            $meta = new Metadata('newttcopy');
            $meta->data = microtime(TRUE);
            $meta->dataNAME = 'timeOfCreation';
            $meta->refID = '007';
            $meta->refTO = 'trimesterStep';
            $meta->save();
        
            $this->redirect(array('settings/newTrimPhase'));
            
        }
        
        public function actionClearNewTriDB(){
            //newtimetable, metadata, newenlist cleanup
            Yii::app()->db->createCommand()->truncateTable('metadata');
            Yii::app()->db->createCommand()->truncateTable('newenlist');
            Yii::app()->db->createCommand()->truncateTable('newtimetable');
            
            $meta = new Metadata('clear new trim');
            $meta->data = microtime(TRUE);
            $meta->dataNAME = 'timeOfCreation';
            $meta->refID = '001';
            $meta->refTO = 'trimesterStep';
            $meta->save();
            
            $this->redirect(array('settings/newTrimPhase'));
        }
	
	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return Settings the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=Settings::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param Settings $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='settings-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
}
