<?php

class SpravaController extends Controller {

    public $layout = 'manazment';

    public function init() {
        Yii::app()->errorHandler->errorAction = 'sprava/error';
    }

    /**
     * Declares class-based actions.
     */
    public function actions() {
        return array(
            // captcha action renders the CAPTCHA image displayed on the contact page
            'captcha' => array(
                'class' => 'CCaptchaAction',
                'backColor' => 0xFFFFFF,
            ),
            // page action renders "static" pages stored under 'protected/views/site/pages'
            // They can be accessed via: index.php?r=site/page&view=FileName
            'page' => array(
                'class' => 'CViewAction',
            ),
        );
    }

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array(''),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array(''),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('captcha', 'index', 'deti', 'upravDeti', 'nastavenia', 'error', 'contact', /* 'tentoTyzden', */ 'novyTrim', 'pokracovanie', 'novyQuery', 'nepokracovanie', 'novyRozvrh', 'novyRozvrhAlt', 'prihlasitNaRozvrh', 'odhlasitZRozvrhu_', /*'odhlasitZRozvrhu',*/ 'potvrdOdhlasenie'),
                //'users'=>array('admin'),
                'expression' => array('SpravaController', 'allowOnlyOwner')
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Allow only the owner to do the action
     * @return boolean whether or not the user is the owner
     */
    public function allowOnlyOwner() {
        if (isset(Yii::app()->user->userRightsId)) {
            if (Yii::app()->user->userRightsId == '2') {
                return true;
            } else {
                $example = Users::model()->findByPk($_GET["id"]);
                $this->example = $example;
                return $example->uid === Yii::app()->user->id;
            }
        } else {
            return false;
        }
    }

    /**
     * This is the default 'index' action that is invoked
     * when an action is not explicitly requested by users.
     */
    public function actionIndex() {
        $this->layout = '//layouts/manazment';
        // renders the view file 'protected/views/site/index.php'
        // using the default layout 'protected/views/layouts/main.php'
        $this->render('index');
    }

    public function actionDeti() {
        $this->layout = '//layouts/manazment';

        $curU = Users::model()->findByPk(Yii::app()->user->getId());
        $children = Kids::model()->with(array('enlists', 'payments'))->findAllByAttributes(array('parrent_ID' => $curU->ID));
        $three_choices = Settings::model()->findByAttributes(array('type' => 'new_trim_allowed'));
        $diff_tt = Settings::model()->findByAttributes(array('type'=>'new_trim_timetable_change'));
        $diff_tt_short = Settings::model()->findByAttributes(array('type'=>'new_trim_timetable_change_short'));
        $showall_tt_change = Settings::model()->findByAttributes(array('type'=>'show_all_tt_change'));
        
        $this->render('deti', array('user' => $curU, 'children' => $children, 'show_new_trim' => $three_choices, 'show_diff_tt'=>$diff_tt, 'show_diff_tt_short'=>$diff_tt_short, 'showall_tt_change'=>$showall_tt_change));
    }

    public function actionUpravDeti($id) {
        $this->layout = '//layouts/manazment';
        $child = Kids::model()->findByPk($id);


        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['Kids'])) {
            $child->attributes = $_POST['Kids'];
            if ($child->save()){
                Yii::app()->user->setFlash('success', "Zmeny boli úspešne uložené.");
                $this->redirect(array('upravDeti', 'id' => $child->ID));
            }
        }

        $this->render('upravDeti', array('model' => $child));
    }

    public function actionNastavenia() {
        $this->layout = '//layouts/manazment';
        $model = Users::model()->findByPk(Yii::app()->user->getId());


        if (isset($_POST['Users'])) {
            if ($_POST['Users']['password'] == '' || (!(isset($_POST['Users']['password'])))) {
                $_POST['Users']['password'] = $model->password;
            } else {
                if ($_POST['Users']['password'] == $_POST['Users']['password2']) {
                    $_POST['Users']['password'] = hash('sha256', $_POST['Users']['password']);
                    Yii::app()->user->setFlash('success', "Heslo bolo úspešne uložené!");
                } else {
                    Yii::app()->user->setFlash('error', "Heslo nebolo uložené! Zadajte 2x rovnaké heslo.");
                }
            }
            $model->attributes = $_POST['Users'];
            if ($model->save()) {
                Yii::app()->user->setFlash('success', "Dáta boli úspešne uložené!");
                $this->redirect(array('nastavenia', 'id' => $model->ID, 'status' => 'success'));
            }
        }

        $model->password = "";
        $this->render('nastavenia', array('model' => $model));
    }

    /**
     * This is the action to handle external exceptions.
     */
    public function actionError() {
        $this->layout = '//layouts/manazment';
        if ($error = Yii::app()->errorHandler->error) {
            if (Yii::app()->request->isAjaxRequest)
                echo $error['message'];
            else
                $this->render('error', $error);
        }
    }

    /**
     * Displays the contact page
     */
    public function actionContact() {
        $this->layout = '//layouts/manazment';
        $model = new ContactForm;
        if (isset($_POST['ContactForm'])) {
            $model->attributes = $_POST['ContactForm'];
            if ($model->validate()) {
                $name = '=?UTF-8?B?' . base64_encode($model->name) . '?=';
                $subject = '=?UTF-8?B?' . base64_encode($model->subject) . '?=';
                $headers = "From: $name <{$model->email}>\r\n" .
                        "Reply-To: {$model->email}\r\n" .
                        "MIME-Version: 1.0\r\n" .
                        "Content-Type: text/plain; charset=UTF-8";
                $body = 'Mail od: ' . $model->email . ' ';
                $body .= $model->body;
                //mail(Yii::app()->params['adminEmail'], $subject, $model->body, $headers);
                mail('samorin@bighuggym.sk', 'Kontaktý formulár - systém -  ' . $subject, $model->body, $headers);
                Yii::app()->user->setFlash('contact', 'Thank you for contacting us. We will respond to you as soon as possible.');
                $this->refresh();
            }
        }
        $this->render('contact', array('model' => $model));
    }

    public function actionPrihlasitNaRozvrh($id) {
        date_default_timezone_set('CET');
        $this->layout = '//layouts/manazment';
        $curU = Users::model()->findByPk(Yii::app()->user->getId());

        $timet = array();

        $kid = Kids::model()->findByAttributes(array(
            'ID' => $id,
            'parrent_ID' => $curU->ID,
        ));

        if (isset($_POST)) {
            //pokial je dlzka $_POST['hours'] > ako volne hodiny, tak NIC!
            if (isset($_POST['hours'])) {
                if (count($_POST['hours']) <= $kid->refund) {
                    $hodiny = "";
                    foreach ($_POST['hours'] as $single) {

                        $ww = explode('_', $single);

                        $timetable = Timetable::model()->findByPk($ww[0]);

                        $mod = new Hours('GenSemester');
                        $mod->date = $ww[1];
                        $mod->ID_timet = $timetable->ID;
                        $mod->week_day = $timetable->week_day;
                        $mod->time_start = $timetable->time_start;
                        $mod->time_end = $timetable->time_end;
                        $mod->lesson = $timetable->lesson;
                        $mod->trainer = $timetable->trainer;
                        $mod->trainer_alt = $timetable->trainer_alt;
                        $mod->ID_kids = $id;
                        $mod->name = $kid->name;
                        $mod->surname = $kid->surname;
                        $mod->present = 0;
                        $mod->tryout = 0;
                        $mod->notes = NULL;
                        $duplicity = Hours::model()->findAllByAttributes(array(
                            'date' => $ww[1],
                            'ID_kids' => $id,
                            'time_start' => $timetable->time_start
                        ));
                        if ($mod->validate() && (!(isset($duplicity[0]->ID)))) {
                            if ($mod->save()) {
                                $hodiny .= "v $mod->date od $mod->time_start, ";
                                //pridaj nove hours, odcitaj z volnych hodin
                                $kid->refund = $kid->refund - 1;
                                //echo $kid->refund - $added;
                                $kid->save();
                            }
                        } else {
                            Yii::app()->user->setFlash('error', "Nastala chyba pri ukladaní náhradných hodín. Skúste znovu. Ak chyba pretrváva, kontaktujte prosím BigHugGym.");
                        }
                    }
                    Yii::app()->user->setFlash('success', "Ďakujeme, náhradné hodiny vo Vami zvolenom čase - $hodiny - boli úspešne uložené.");
                } else {
                    //zobrazit err
                    Yii::app()->user->setFlash('notice', "Nastala chyba pri ukladaní náhradných hodín. Skúste znovu. Ak chyba pretrváva, kontaktujte prosím BigHugGym.");
                }
            }
        }

        $thisenl = Enlist::model()->with(array('iDTimet'))->findByAttributes(array(
            'ID_kid' => $id,
        ));


        $timetables = Timetable::model()->with(array(
                    'gym',
                    'trainer0',
                ))->findAllByAttributes(array(
            'lesson' => $thisenl->iDTimet->lesson,
            'active' => '1',
//            'lesson' => $kid->lesson,
        ));

        if (isset($timetables[0])) {
            $cap = $timetables[0]->gym->capacity;
        } else {
            $cap = 0;
        }

        $IDees = array();

        $i = date('N', strtotime("+1 day", strtotime(date('Y-m-d')))) - 1;
        $date = date('Y-m-d', strtotime("+1 day", strtotime(date('Y-m-d'))));
        $end_date = date('Y-m-d', strtotime("+7 day", strtotime($date)));

        while (strtotime($date) < strtotime($end_date)) {
            $today = array();
            foreach ($timetables as $tt) {
                if (($tt->week_day - 1) == $i) {
                    $today[] = $tt;
                    $timet[$i][] = $tt;
                } else {
                    $timet[$i][] = array();
                }
            }

            if (!empty($today)) {
                foreach ($today as $t) {
                    $hours[$i][$t->ID] = Hours::model()->findAllByAttributes(array(
                        'ID_timet' => $t->ID,
                        'date' => $date,
                    ));
                    foreach ($hours[$i][$t->ID] as $single) {
                        if ($single->ID_kids == $kid->ID) {
                            $IDees[] = $single->ID;
                        }
                    }
                }
            } else {
                $hours[$i] = array();
            }

            $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            $i++;
            $i = $i % 7;
        }


        //ak post tak pridat hodinu

        $hdays = Holiday::model()->findAll();

        foreach ($hdays as $hday) {
            $date = $hday->date_start;
            while (strtotime($date) <= strtotime($hday->date_end)) {
                $holidays[] = $date;
                $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            }
        }

        $this->render('prihlasNaRozvrh', array('hours' => $hours, 'timetables' => $timet, 'kid' => $kid, 'cap' => $cap, 'hdays' => $holidays, 'debug' => $IDees));
    }

    public function actionOdhlasitZRozvrhu_($id){
        date_default_timezone_set('Europe/Bratislava');    
        $date = date('Y-m-d', strtotime('+12 hours'));
        $ftime = date('H:i:s', strtotime('+12 hours')); //future time
        $hours = Hours::model()->findAll(array(
            'order'=>'date',
            'condition'=>'ID_kids=:kid_id AND ((date = :date AND time_start>=:ftime) OR (date > :date))',
            'params'=>array(':kid_id'=>$id, ':date'=>$date, ':ftime'=>$ftime),
        ));
        $this->render('odhlasitZRozvrhu_',array('hours'=>$hours, 'now'=>$date .' '. $ftime));
    }
    
    public function actionPotvrdOdhlasenie(){
        $hours = array();
        if(isset($_POST['delete'])){
            foreach($_POST['delete'] as $single){
                $hours[] = Hours::model()->findByPk($single);
            }
        }
        
        if(isset($_POST['unmake'])){           
            foreach($_POST['sure'] as $single){
                $h = Hours::model()->findByPk($single);
                $pk = $h->ID_kids;
                $h->delete();
            }
            $kid = Kids::model()->findbyPK($pk);
            $kid->refund = $kid->refund + count($_POST['sure']);
            $kid->save();
            Yii::app()->user->setFlash('success', "Hodiny boli úspešne zmazané. Počet náhradných hodín bol navýseny o ".count($_POST['sure']));    
            $this->redirect(array('sprava/odhlasitZRozvrhu_', 'id'=>$kid->ID));
        } else {
            $this->render('potvrdOdhlasenie', array('hours'=>$hours));
        }
        
    }
    
    public function actionOdhlasitZRozvrhu($id) {
        date_default_timezone_set('CET');
        $this->layout = '//layouts/manazment';
        $curU = Users::model()->findByPk(Yii::app()->user->getId());

        $thisenl = Enlist::model()->with(array('iDTimet'))->findByAttributes(array(
            'ID_kid' => $id,
        ));

        $timet = array();

        $kid = Kids::model()->findByAttributes(array(
            'ID' => $id,
            'parrent_ID' => $curU->ID,
        ));

        $timetables = Timetable::model()->with(array(
                    'gym',
                    'trainer0',
                ))->findAllByAttributes(array(
//            'lesson' => $kid->lesson,
            'lesson' => $thisenl->iDTimet->lesson,
            'active' => '1',
        ));

        if (isset($timetables[0])) {
            $cap = $timetables[0]->gym->capacity;
        } else {
            $cap = 0;
        }

        $IDees = array();

        $i = date('N', strtotime("+1 day", strtotime(date('Y-m-d')))) - 1;
        $date = date('Y-m-d', strtotime("+1 day", strtotime(date('Y-m-d'))));
        $end_date = date('Y-m-d', strtotime("+7 day", strtotime($date)));

        while (strtotime($date) < strtotime($end_date)) {
            $today = array();
            $debug = array();
            foreach ($timetables as $tt) {
                if (($tt->week_day - 1) == $i) {
                    $today[] = $tt;
                    $timet[$i][] = $tt;
                } else {
                    $timet[$i][] = array();
                }
            }

            if (!empty($today)) {
                foreach ($today as $t) {
                    $hours[$i][$t->ID] = Hours::model()->findAllByAttributes(array(
                        'ID_timet' => $t->ID,
                        'date' => $date,
                    ));
                    foreach ($hours[$i][$t->ID] as $single) {
                        if ($single->ID_kids == $kid->ID) {
                            $IDees[] = $single->ID;
                        }
                    }
                }
            } else {
                $hours[$i] = array();
            }

            $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            $i++;
            $i = $i % 7;
        }

        if (isset($_POST['alter'])) {
            if (!(isset($_POST['notdelete']))) {
                $_POST['notdelete'] = array();
            }
            $deleted = 0;
            if (isset($_POST['notdelete'])) {
                foreach ($IDees as $it => $key) {
                    if (!(in_array($key, $_POST['notdelete']))) {
                        Hours::model()->findByPk($key)->delete();
                        $debug[] = 'Would delete: ' . $key;
                        $deleted++;
                        unset($IDees[$it]);
                    }
                }

                $kid->refund = $kid->refund + $deleted;
                if (($kid->save()) && ($deleted != 0)) {
                    Yii::app()->user->setFlash('success', "Hodiny boli úspešne zmenené.");
                } else {
                    Yii::app()->user->setFlash('notice', "Hodiny neboli upravené.");
                }

                //zmaz stare hours + pridaj dietatu volnu hodinu 
            }
            //$this->redirect(array('sprava/odhlasitZRozvrhu', 'id' => $id));
        }
        //ak post tak pridat hodinu
        //----------------------------------------------------------------------
        $timet = array();
        $IDees = array();

        $i = date('N', strtotime("+1 day", strtotime(date('Y-m-d')))) - 1;
        $date = date('Y-m-d', strtotime("+1 day", strtotime(date('Y-m-d'))));
        $end_date = date('Y-m-d', strtotime("+7 day", strtotime($date)));

        while (strtotime($date) < strtotime($end_date)) {
            $today = array();
            foreach ($timetables as $tt) {
                if (($tt->week_day - 1) == $i) {
                    $today[] = $tt;
                    $timet[$i][] = $tt;
                } else {
                    $timet[$i][] = array();
                }
            }

            if (!empty($today)) {
                foreach ($today as $t) {
                    $hours[$i][$t->ID] = Hours::model()->findAllByAttributes(array(
                        'ID_timet' => $t->ID,
                        'date' => $date,
                    ));
                    foreach ($hours[$i][$t->ID] as $single) {
                        if ($single->ID_kids == $kid->ID) {
                            $IDees[] = $single->ID;
                        }
                    }
                }
            } else {
                $hours[$i] = array();
            }

            $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            $i++;
            $i = $i % 7;
        }
        //----------------------------------------------------------------------

        $hdays = Holiday::model()->findAll();

        foreach ($hdays as $hday) {
            $date = $hday->date_start;
            while (strtotime($date) <= strtotime($hday->date_end)) {
                $holidays[] = $date;
                $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            }
        }

        $this->render('odhlasitZRozvrhu', array('hours' => $hours, 'timetables' => $timet, 'kid' => $kid, 'cap' => $cap, 'hdays' => $holidays, 'debug' => $debug));
    }

    public function actionTentoTyzden($id) {
        date_default_timezone_set('CET');
        $this->layout = '//layouts/manazment';
        $curU = Users::model()->findByPk(Yii::app()->user->getId());

        $timet = array();

        $kid = Kids::model()->findByAttributes(array(
            'ID' => $id,
            'parrent_ID' => $curU->ID,
        ));

        $timetables = Timetable::model()->with(array(
                    'gym',
                    'trainer0',
                ))->findAllByAttributes(array(
            'lesson' => $kid->lesson,
            'active' => '1',
        ));

        if (isset($timetables[0])) {
            $cap = $timetables[0]->gym->capacity;
        } else {
            $cap = 0;
        }

        $IDees = array();

        $i = date('N', strtotime("+1 day", strtotime(date('Y-m-d')))) - 1;
        $date = date('Y-m-d', strtotime("+1 day", strtotime(date('Y-m-d'))));
        $end_date = date('Y-m-d', strtotime("+7 day", strtotime($date)));

        while (strtotime($date) < strtotime($end_date)) {
            $today = array();
            foreach ($timetables as $tt) {
                if (($tt->week_day - 1) == $i) {
                    $today[] = $tt;
                    $timet[$i][] = $tt;
                } else {
                    $timet[$i][] = array();
                }
            }

            if (!empty($today)) {
                foreach ($today as $t) {
                    $hours[$i][$t->ID] = Hours::model()->findAllByAttributes(array(
                        'ID_timet' => $t->ID,
                        'date' => $date,
                    ));
                    foreach ($hours[$i][$t->ID] as $single) {
                        if ($single->ID_kids == $kid->ID) {
                            $IDees[] = $single->ID;
                        }
                    }
                }
            } else {
                $hours[$i] = array();
            }

            $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            $i++;
            $i = $i % 7;
        }

        //$a=array();

        if (isset($_POST['alter']) && ( $_POST['free'] >= 0 )) {
            //dat pozor na maximalny pocet uprav
            $DID = array();

            if (!(isset($_POST['notdelete']))) {
                $_POST['notdelete'] = array();
            }
            $deleted = 0;
            if (isset($_POST['notdelete'])) {
                foreach ($IDees as $key) {
                    if (!(in_array($key, $_POST['notdelete']))) {
                        Hours::model()->findByPk($key)->delete();
                        //echo 'deleted '.$key;             
                        $deleted++;
                    }
                }

                $kid->refund = $kid->refund + $deleted;
                $kid->save();
                //zmaz stare enlisty + pridaj dietatu volnu hodinu   
            }

            $added = 0;
            if (isset($_POST['hours'])) {
                foreach ($_POST['hours'] as $single) {

                    $ww = explode('_', $single);

                    $timetable = Timetable::model()->findByPk($ww[0]);

                    $mod = new Hours('GenSemester');
                    $mod->date = $ww[1];
                    $mod->ID_timet = $timetable->ID;
                    $mod->week_day = $timetable->week_day;
                    $mod->time_start = $timetable->time_start;
                    $mod->time_end = $timetable->time_end;
                    $mod->lesson = $timetable->lesson;
                    $mod->trainer = $timetable->trainer;
                    $mod->trainer_alt = $timetable->trainer_alt;
                    $mod->ID_kids = $id;
                    $mod->name = $kid->name;
                    $mod->surname = $kid->surname;
                    $mod->present = 0;
                    $mod->tryout = 0;
                    $mod->notes = NULL;
                    if ($mod->validate()) {
                        $mod->save();
                        //print_r($mod);              
                        $added++;
                    }
                }
                //pridaj nove hours, odcitaj z volnych hodin
                $kid->refund = $kid->refund - $added;
                //echo $kid->refund - $added;
                $kid->save();
            }

            //reinit

            $IDees = array();
            $hours = array();
            $timet = array();

            $i = date('N', strtotime("+1 day", strtotime(date('Y-m-d')))) - 1;
            $date = date('Y-m-d', strtotime("+1 day", strtotime(date('Y-m-d'))));
            $end_date = date('Y-m-d', strtotime("+7 day", strtotime($date)));

            while (strtotime($date) < strtotime($end_date)) {
                $today = array();
                foreach ($timetables as $tt) {
                    if (($tt->week_day - 1) == $i) {
                        $today[] = $tt;
                        $timet[$i][] = $tt;
                    } else {
                        $timet[$i][] = array();
                    }
                }

                if (!empty($today)) {
                    foreach ($today as $t) {
                        $hours[$i][$t->ID] = Hours::model()->findAllByAttributes(array(
                            'ID_timet' => $t->ID,
                            'date' => $date,
                        ));
                        foreach ($hours[$i][$t->ID] as $single) {
                            if ($single->ID_kids == $kid->ID) {
                                $IDees[] = $single->ID;
                            }
                        }
                    }
                } else {
                    $hours[$i] = array();
                }

                $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
                $i++;
                $i = $i % 7;
            }
            //print_r($_POST);
        } elseif (isset($_POST['alter']) && ( $_POST['free'] < 0 )) {
            echo "Vyskytla sa chyba pri ukladaní.";
        }
        //pribalit vsetky prazdniny
        $hdays = Holiday::model()->findAll();

        foreach ($hdays as $hday) {
            $date = $hday->date_start;
            while (strtotime($date) <= strtotime($hday->date_end)) {
                $holidays[] = $date;
                $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            }
        }

        $this->render('tentoTyzden', array('hours' => $hours, 'timetables' => $timet, 'kid' => $kid, 'cap' => $cap, 'hdays' => $holidays, 'debug' => $IDees));
    }

    public function actionTentoTyzdenOld($id) {
        date_default_timezone_set('CET');
        $this->layout = '//layouts/manazment';
        $curU = Users::model()->findByPk(Yii::app()->user->getId());

        $data = array();

        $kid = Kids::model()->findByAttributes(array(
            'ID' => $id,
            'parrent_ID' => $curU->ID,
        ));

        $timet = Timetable::model()->with(array(
                    'gym',
                ))->findAllByAttributes(array(
            'lesson' => $kid->lesson,
        ));

        if (isset($timet[0])) {
            $cap = $timet[0]->gym->capacity;
        } else {
            $cap = 0;
        }

        $c = 0;
        $i = date('N') - 1;
        $date = date('Y-m-d');
        $end_date = date('Y-m-d', strtotime("+7 day", strtotime($date)));

        $IDees = array();

        while (strtotime($date) < strtotime($end_date)) {
            $data[$i] = Hours::model()->findAllByAttributes(array(
                'ID_kids' => $kid->ID,
                'date' => $date,
            ));
            $alldata[$i] = Hours::model()->findAllByAttributes(array(
                'date' => $date,
                'lesson' => $kid->lesson,
            ));
            foreach ($data[$i] as $single) {
                $data[$i]['hours'][] = $single->time_start;
                $c++;
                $IDees[] = $single->ID;
            }
            foreach ($alldata[$i] as $single) {
                $alldata[$i]['hours'][] = $single->time_start;
            }
            $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            $i++;
            $i = $i % 7;  //indexy su od 1-7 cize nie nutne dobre. kurva.    
        }

        //$a=array();

        if (isset($_POST['alter']) && ( $_POST['free'] >= 0 )) {
            //dat pozor na maximalny pocet uprav
            $DID = array();

            if (!(isset($_POST['notdelete']))) {
                $_POST['notdelete'] = array();
            }
            $deleted = 0;
            if (isset($_POST['notdelete'])) {
                foreach ($IDees as $key) {
                    if (!(in_array($key, $_POST['notdelete']))) {
                        Hours::model()->findByPk($key)->delete();
                        $deleted++;
                    }
                }

                $kid->refund = $kid->refund + $deleted;
                $kid->save();
                //zmaz stare enlisty + pridaj dietatu volnu hodinu   
            }

            $added = 0;
            if (isset($_POST['hours'])) {
                foreach ($_POST['hours'] as $single) {

                    $ww = explode('_', $single);

                    $timetable = Timetable::model()->findByPk($ww[0]);

                    $mod = new Hours('GenSemester');
                    $mod->date = $ww[1];
                    $mod->ID_timet = $timetable->ID;
                    $mod->week_day = $timetable->week_day;
                    $mod->time_start = $timetable->time_start;
                    $mod->time_end = $timetable->time_end;
                    $mod->lesson = $timetable->lesson;
                    $mod->trainer = $timetable->trainer;
                    $mod->trainer_alt = $timetable->trainer_alt;
                    $mod->ID_kids = $id;
                    $mod->name = $kid->name;
                    $mod->surname = $kid->surname;
                    $mod->present = 0;
                    $mod->tryout = 0;
                    $mod->notes = NULL;
                    if ($mod->validate()) {
                        $mod->save();
                        $added++;
                    }
                }
                //pridaj nove hours, odcitaj z volnych hodin
                $kid->refund = $kid->refund - $added;
                $kid->save();
            }

            //reinit

            $c = 0;
            $i = date('N') - 1;
            $date = date('Y-m-d');
            $end_date = date('Y-m-d', strtotime("+7 day", strtotime($date)));

            $IDees = array();

            while (strtotime($date) < strtotime($end_date)) {
                $data[$i] = Hours::model()->findAllByAttributes(array(
                    'ID_kids' => $kid->ID,
                    'date' => $date,
                ));
                $alldata[$i] = Hours::model()->findAllByAttributes(array(
                    'date' => $date,
                    'lesson' => $kid->lesson,
                ));
                foreach ($data[$i] as $single) {
                    $data[$i]['hours'][] = $single->time_start;
                    $c++;
                    $IDees[] = $single->ID;
                }
                foreach ($alldata[$i] as $single) {
                    $alldata[$i]['hours'][] = $single->time_start;
                }
                $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
                $i++;
                $i = $i % 7;  //to iste co pred tym    
            }
            //print_r($_POST);
        } elseif (isset($_POST['alter']) && ( $_POST['free'] < 0 )) {
            echo "Vyskytla sa chyba pri ukladaní.";
        }

        $tt = array();
        foreach ($timet as $single) {
            $tt[$single->week_day - 1][] = $single;
            $tt[$single->week_day - 1]['hours'][] = $single->time_start;
        }

        $this->render('tentoTyzden', array('prihlaseny' => $alldata, 'dieta' => $data, 'kid' => $id, 'chkd' => $c, 'tt' => $tt, 'cap' => $cap, 'free' => $kid->refund));
    }

    public function actionNovyTrim($id) {
        $this->layout = '//layouts/manazment';
        $curU = Users::model()->findByPk(Yii::app()->user->getId());
        $kid = Kids::model()->findByAttributes(array(
            'ID' => $id,
                //'parrent_ID' => $curU->ID,
        ));

        $val = Metadata::model()->findByAttributes(array(
            'refTO' => 'dieta',
            'refID' => $id,
            'dataNAME' => 'hlasovanie',
        ));

        if (count($val) != 0) {
            $val = $val->data;
        } else {
            $val = 0;
        }

        $this->render('novyTrim', array('id' => $id, 'dieta' => $kid, 'already' => $val));
    }

    public function actionPokracovanie($id) {
        $this->layout = '//layouts/manazment';
        /*
          $curU = Users::model()->findByPk(Yii::app()->user->getId());
          $dieta = Kids::model()->findByAttributes(array(
          'ID' => $id,
          'parrent_ID' => $curU->ID,
          ));
         */
        $dieta = Kids::model()->findByPk($id);

        $enlist = Enlist::model()->with('iDTimet')->findAllByAttributes(array(
            'ID_kid' => $id
        ));
        if (isset($_POST['skopiruj'])) {
            foreach ($enlist as $single) {
                $nenl = new Newenlist();
                $nenl->setAttributes($single->getAttributes(), false);
                $nenl->save();
            }

            $zapis = new Metadata('hlasovanie');
            $zapis->refID = $id;
            $zapis->refTO = 'dieta';
            $zapis->dataNAME = 'hlasovanie';
            $zapis->data = '1'; //bolo zahlasovane;
            $zapis->save();

            $thiskid = Kids::model()->findByPk($id);

            $zapis1 = new Metadata('hlasovanie_r');
            $zapis1->refID = $thiskid->parrent_ID;
            $zapis1->refTO = 'rodic';
            $zapis1->dataNAME = 'hlasoval';
            $zapis1->data = '1'; //bolo zahlasovane;
            $zapis1->save();

            $this->redirect(array('sprava/novyTrim', 'id' => $id)); // presmerovanie na deti
        }
        $this->render('pokracovanie', array('id' => $id, 'enl' => $enlist, 'dieta' => $dieta));
    }

    public function actionNovyQuery($id) {
        //kid_id
        //zapis do query podla rozvrhu.
        $curU = Users::model()->findByPk(Yii::app()->user->getId());
        $dieta = Kids::model()->findByAttributes(array(
            'ID' => $id,
                //'parrent_ID' => $curU->ID,
        ));
        if (isset($_POST['zmenit'])) {
            $zapis = new Metadata('zmenit');
            $zapis->refID = $id;
            $zapis->refTO = 'dieta';
            $zapis->dataNAME = 'pokracovanie';
            $zapis->data = '1'; //nechce pokracovat;
            $zapis->save();
            //print_r($zapis->validate());

            $zapis0 = new Metadata('hlasovanie');
            $zapis0->refID = $id;
            $zapis0->refTO = 'dieta';
            $zapis0->dataNAME = 'hlasovanie';
            $zapis0->data = '1'; //bolo zahlasovane;
            $zapis0->save();

            $thiskid = Kids::model()->findByPk($id);

            $zapis1 = new Metadata('hlasovanie_r');
            $zapis1->refID = $thiskid->parrent_ID;
            $zapis1->refTO = 'rodic';
            $zapis1->dataNAME = 'hlasoval';
            $zapis1->data = '1'; //bolo zahlasovane;
            $zapis1->save();

            //print_r($zapis0->validate());
            $this->redirect(array('sprava/novyTrim', 'id' => $id));
        }
        $this->render('novyQuery', array('id' => $id, 'dieta' => $dieta));
    }

    public function actionNepokracovanie($id) {
        //nezela si pokracovat? co tu? deaktivacia dietata, rodica?
        /**
         * This is the model class for table "metadata".
         *
         * The followings are the available columns in table 'metadata':
         * @property integer $ID
         * @property string $refTO
         * @property integer $refID
         * @property integer $dataNAME
         * @property string $data
         */
        $curU = Users::model()->findByPk(Yii::app()->user->getId());
        $dieta = Kids::model()->findByAttributes(array(
            'ID' => $id,
            'parrent_ID' => $curU->ID,
        ));

        if (isset($_POST['skoncit'])) {
            $zapis = new Metadata('skoncit');
            $zapis->refID = $id;
            $zapis->refTO = 'dieta';
            $zapis->dataNAME = 'pokracovanie';
            $zapis->data = '0'; //nechce pokracovat;
            $zapis->save();

            $zapis0 = new Metadata('hlasovanie');
            $zapis0->refID = $id;
            $zapis0->refTO = 'dieta';
            $zapis0->dataNAME = 'hlasovanie';
            $zapis0->data = '1'; //bolo zahlasovane;
            $zapis0->save();

            $thiskid = Kids::model()->findByPk($id);

            $zapis1 = new Metadata('hlasovanie_r');
            $zapis1->refID = $thiskid->parrent_ID;
            $zapis1->refTO = 'rodic';
            $zapis1->dataNAME = 'hlasoval';
            $zapis1->data = '1'; //bolo zahlasovane;
            $zapis1->save();

            $this->redirect(array('sprava/novyTrim', 'id' => $id));
        }
        //@print_r($_POST);
        $this->render('nepokracovanie', array('id' => $id, 'dieta' => $dieta));
    }

    public function validateDate($date, $format = 'd.m.Y') {
        $d = DateTime::createFromFormat($format, $date);
        return $d && $d->format($format) == $date;
    }

    public function getClass($born) {
        $tz = new DateTimeZone('Europe/Brussels');
        $age = DateTime::createFromFormat('d.m.Y', $born, $tz)
                        ->diff(new DateTime('now', $tz))
                ->y;
        //if
        //  pokial to je menej ako 2 roky, tak -> pozriet mesiace
        //  inak 

        if (($age >= 1) && ($age < 2)) {
            //viac kao 16 mesiacov!!
            return "hrosikovia";
        }
        if (($age >= 2) && ($age < 4)) {
            return "zabky";
        }
        if (($age >= 4) && ($age < 7)) {
            return "zajacikovia";
        }
        if (($age >= 7) && ($age < 10)) {
            return "orangutani";
        }
        if (($age >= 10) && ($age < 13)) {
            return "gepardi";
        }
        if (($age >= 13) && ($age < 18)) {
            return "levy";
        }


        /*
          <option value="hrosikovia">Hrošíkovia (16 - 24 MESIACOV)</option>
          <option value="zabky">Žabky (2 - 3 ROKY)</option>
          <option value="zajacikovia">Zajačikovia (4 - 6 ROKOV)</option>
          <option value="orangutani">Orangutani (7 - 9 ROKOV)</option>
          <option value="gepardi">Gepardi (10 - 12ROKOV )</option>
          <option value="levy">Levy (13+ ROKOV)</option>
         */
    }

    public function actionNovyRozvrhAlt($id) {

        $dieta = Kids::model()->findByPk($id);
        /*
          $curU = Users::model()->findByPk(Yii::app()->user->getId());
          $dieta = Kids::model()->findByAttributes(array(
          'ID' => $id,
          'parrent_ID' => $curU->ID,
          ));
         */


        if ($this->validateDate($dieta->birthday)) {
            $message = NULL;
            $class = $this->getClass($dieta->birthday);
            $rozvrhy = Newtimetable::model()->with('trainer0', 'newenlists', 'gym')->findAllByAttributes(array(
                'lesson' => $class,
            ));


            if (isset($_POST['ulozit_rozvrh'])) {
                if (isset($_POST['Enlist'])) {
                    if ((count($_POST['Enlist']) >= 1) && (count($_POST['Enlist']) < 3 )) {
                        //zapisat pocet hodin
                        $pocet = count($_POST['Enlist']);

                        $dieta->frequency = $pocet;
                        $dieta->save();

                        foreach ($_POST['Enlist'] as $single) {
                            $emod = new Newenlist('nova_reg');
                            $emod->ID_kid = $id;
                            $emod->ID_timet = $single;
                            $emod->save();
                        }
                        //zapisat enlisty


                        $meta = new Metadata('nova_reg');
                        $meta->refID = $dieta->ID;
                        $meta->refTO = 'dieta';
                        $meta->dataNAME = 'rozvrh_zmeneny';
                        $meta->data = '1'; //bolo zahlasovane;
                        $meta->save();
                        //zapisat metatag aby sa nedalo 2x

                        $this->redirect(array('deti'));
                    } else {
                        $message = "Zadali ste príliš veľa alebo žiadnu hodinu.<br /> <b> Môžeťe si vybrať 1 až 2 možné hodiny z ponúkaných kurzov.</b>" . '<br /><b>' . CHtml::link('Späť', array('sprava/novyRozvrh', "id" => $child->ID), array('style' => 'color: red;')) . '</b>';
                    }
                }
            }
        } else {
            $message = "Prosím, doplňte <b>správny dátum narodenia</b> Vášho dieťaťa <b>vo formáte DD.MM.RRRR</b> (31.01.2015) v jeho vizitke tu: <br /> <a href='" . Yii::app()->createUrl("sprava/upravDeti", array('id' => $dieta->ID)) . "' >" . $dieta->name . ' ' . $dieta->surname . "</a>";
            $rozvrhy = NULL;
        }


        $this->render('novyRozvrhAlt', array('msg' => $message, 'rozvrhy' => $rozvrhy, 'id' => $id, 'child' => $dieta));
    }

    public function actionNovyRozvrh($id) {

        $dieta = Kids::model()->findByPk($id);
        /*
          $curU = Users::model()->findByPk(Yii::app()->user->getId());
          $dieta = Kids::model()->findByAttributes(array(
          'ID' => $id,
          'parrent_ID' => $curU->ID,
          ));
         */

        //pokial nema enlisty, tak....

        $enl = Enlist::model()->findAllByAttributes(array(
            'ID_kid' => $id,
        ));

        if (sizeof($enl) == 0) {

            if ($this->validateDate($dieta->birthday)) {
                $message = NULL;
                $class = $this->getClass($dieta->birthday);
                $rozvrhy = Timetable::model()->with('trainer0', 'enlists', 'gym')->findAllByAttributes(array(
                    'lesson' => $class,
                ));


                if (isset($_POST['ulozit_rozvrh'])) {
                    if (isset($_POST['Enlist'])) {
                        if ((count($_POST['Enlist']) >= 1) && (count($_POST['Enlist']) < 3 )) {
                            //zapisat pocet hodin
                            $pocet = count($_POST['Enlist']);

                            $dieta->frequency = $pocet;
                            $dieta->save();

                            foreach ($_POST['Enlist'] as $single) {
                                $emod = new Enlist('nova_reg');
                                $emod->ID_kid = $id;
                                $emod->ID_timet = $single;
                                $emod->save();
                            }
                            //zapisat enlisty


                            $meta = new Metadata('nova_reg');
                            $meta->refID = $dieta->ID;
                            $meta->refTO = 'dieta';
                            $meta->dataNAME = 'rozvrh_zmeneny';
                            $meta->data = '1'; //bolo zahlasovane;
                            $meta->save();
                            //zapisat metatag aby sa nedalo 2x

                            $this->redirect(array('deti'));
                        } else {
                            $message = "Zadali ste príliš veľa alebo žiadnu hodinu.<br /> <b> Môžeťe si vybrať 1 až 2 možnosti z ponúkaných kurzov.</b>" . '<br /><b>' . CHtml::link('Späť', array('sprava/novyRozvrh', "id" => $child->ID), array('style' => 'color: red;')) . '</b>';
                        }
                    }
                }
            } else {
                $message = "Prosím, doplňte <b>správny dátum narodenia</b> Vášho dieťaťa <b>vo formáte DD.MM.RRRR</b> (31.01.2015) v jeho vizitke tu: <br /> <a href='" . Yii::app()->createUrl("sprava/upravDeti", array('id' => $dieta->ID)) . "' >" . $dieta->name . ' ' . $dieta->surname . "</a>";
                $rozvrhy = NULL;
            }
        } else {
            $message = "Vaše dieťa už bolo zapísané na rozvrh, v prípade záujmu o zmenu nás prosím kontaktujte.";
            $rozvrhy = NULL;
        }


        $this->render('novyRozvrh', array('msg' => $message, 'rozvrhy' => $rozvrhy, 'id' => $id, 'child' => $dieta));
    }

}
