<?php

define("SENDER_NAME", "BigHugGym");
define("SENDER_EMAIL", "samorin@bighuggym.sk");
define("EMAIL_SUBJECT", "Prihlasovacie údaje do BigHugGym");

class UsersController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column2';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('register'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array(''),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('index', 'view', 'admin', 'delete', 'create', 'update', 'confirmation', 'rozvrh', 'massmail', 'massmailalt', 'deactivateusers', 'lockthem','viewprofile'),
                'users' => array('admin', 'PtacinJan', 'jan.ptacin@gmail.com'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new Users;

        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['Users'])) {
            $model->attributes = $_POST['Users'];
            if ($model->save()) {
                $model->user_name = $model->user_name . '_' . $model->ID;
                $model->save();
                $this->redirect(array('view', 'id' => $model->ID));
            }
        }

        $this->render('create', array(
            'model' => $model,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);
        $password = $model->password;
        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['Users'])) {
            $model->attributes = $_POST['Users'];
            $model->user_name = $model->name . $model->surname . '_' . $model->ID;
            if ($model->password == "") {
                $model->password = $password;
            } else {
                $model->password = hash('sha256', $model->password);
            }
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->ID));
            //print_r($_POST);
        }

        $model->password = "";
        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        $this->loadModel($id)->delete();

        // if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
        if (!isset($_GET['ajax']))
            $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('Users');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new Users('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['Users']))
            $model->attributes = $_GET['Users'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer $id the ID of the model to be loaded
     * @return Users the loaded model
     * @throws CHttpException
     */
    public function loadModel($id) {
        $model = Users::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * send email to user
     */
    /*
      public function sendUserInfo($user_data, $kid_data, $reg_data)
      {
      define( "RECIPIENT_NAME", "BigHugGym" );
      define( "RECIPIENT_EMAIL", "info@bighuggym.com" );
      define( "EMAIL_SUBJECT", "Thank you for your message - BigHugGym.com" );

      $headers  = 'MIME-Version: 1.0' . "\r\n";
      $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";
      $headers .= 'From: ' . RECIPIENT_EMAIL . "\r\n";
      $headers .= 'Reply-To: ' . RECIPIENT_EMAIL . "\r\n";

      mail
      return;
      }
     */

    /**
     * Perform an registration of new user with his child and selected timetable
     *
     *
     */
    /*
      public function actionRegister()
      {
      $this->layout = '//layouts/register-now';

      $umodel=new Users('register');
      $kmodel=new Kids('register');
      $emodel=new Enlist('register');
      $_emodel=new Enlist('register');

      $tts = Timetable::model()->findAll();

      $vsetci = Users::model()->findAll();
      $arr = array();
      $i = 0;
      foreach($vsetci as $v)
      {
      $arr[$i]['mail'] = md5(strtolower($v->email));
      $arr[$i]['phone_num'] = md5($v->phone_num);
      $i++;
      }

      $vsetky_roz = Timetable::model()->findAll();
      $vsetky_prih = Enlist::model()->findAll();


      if(isset($_POST['Users']) && isset($_POST['Kids']) && isset($_POST['Enlist']))
      {
      //defaulting into
      $_POST['Users']['rights_ID']='2';  //rodic


      $md5Hash = md5(microtime());
      $mt = substr($md5Hash,0,8);

      //$dummy = 'heslo';
      $_POST['Users']['secure_hash'] = $mt;
      $_POST['Users']['password'] = $mt;


      //$body = print_r($_POST, true);
      //mail('pales.michael@gmail.com','debuginfo', $body );


      $umodel->attributes=$_POST['Users'];
      $umodel->user_name = substr($md5Hash,0,32);
      $umodel->email = strtolower($_POST['Users']['email']);
      if($umodel->validate())
      {
      if ($umodel->save())
      {
      $umodel->user_name = $_POST['Users']['user_name'].'_'.$umodel->ID;
      $umodel->save();
      $_POST['Kids']['parrent_ID'] = $umodel->ID;
      $kmodel->attributes=$_POST['Kids'];
      if ($kmodel->validate())
      {
      if ($kmodel->save())
      {


      //query SAVE
      $qsave = 3;		// 1 = OK! 2 = failed nieco! 3 = neulozene/neukladane
      foreach($_POST['Query'] as $q){
      $qmodel = new Query('register');
      $qmodel->timet_ID = $q;
      $qmodel->kid_ID = $kmodel->ID;
      //mail('pales.michael@gmail.com','debuginfo', print_r($q, true));
      if ($qmodel->validate()){
      //mail('pales.michael@gmail.com','debuginfo', print_r($q, true));
      if ($qmodel->save()){
      if (($qsave == 1) || ($qsave == 3)){$qsave = 1;}
      } else {
      if (($qsave == 1) || ($qsave == 3)){$qsave = 2;}
      }
      }
      }

      $emodel->ID_timet=$_POST['Enlist']['0'];
      $emodel->ID_kid=$kmodel->ID;

      if (isset($_POST['Enlist'][1])){
      $_emodel->ID_timet=$_POST['Enlist']['1'];
      $_emodel->ID_kid=$kmodel->ID;
      }

      if (($emodel->validate()) && (($_emodel->validate()) || (!(isset($_POST['Enlist']['1'])))))
      {

      if (($emodel->save()) && (($_emodel->save()) || (!(isset($_POST['Enlist']['1'])))))

      {

      $headers  = 'MIME-Version: 1.0' . "\r\n";
      $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";
      $headers .= 'From: ' . SENDER_EMAIL . "\r\n";
      $headers .= 'Reply-To: ' . SENDER_EMAIL . "\r\n";

      $dni = ['pondelok', 'utorok', 'streda', 'štvrtok', 'piatok', 'sobota', 'nedela' ];

      $timetable = Timetable::model()->findByPk($emodel->ID_timet);
      $rcpt = $umodel->email;
      $subj = 'Info BigHugGym.com';
      $msg = '<html><head></head><body>';
      $msg .= 'Ďakujeme za prejavený záujem o skúšobnú hodinu v BigHugGym.
      Dovolujeme si Vás upozorniť, že Váše dieťa, '.$kmodel->name.' '.$kmodel->surname.' očakávame v prvých siedmich ďnoch trimestra, v '. $dni[$timetable->week_day-1] .' o '. substr($timetable->time_start,0,-3). ' na kurze '.$timetable->lesson.'<br /><br />';
      $msg .= 'Semester začína v stredu 02.09.2015. <br /> Tešíme sa na Vás, <br /><br /> BigHugGym Team ';
      $msg .= '</body></html>';
      //$msg .= print_r($_POST, true);
      if (mail($rcpt, $subj, $msg, $headers)){
      $this->redirect(array('users/register', 'mailsent'=>'success', ));
      return;
      }
      }
      }
      }
      }
      }
      }

      }
      $this->render('register',array('model'=>$umodel,'model_k'=>$kmodel,'model_e'=>$emodel,'timet'=>$tts, 'rozvrhy'=>$vsetky_roz, 'prihlasenia'=>$vsetky_prih, 'taken'=>$arr));
      } */


    public function actionRozvrh() {
        $new_enlist = new Enlist('rozvrh');
        $vsetky_roz = Timetable::model()->with(array('trainer0'))->findAll();
        $vsetky_prih = Enlist::model()->findAll();


        $this->render('rozvrh', array('rozvrhy' => $vsetky_roz, 'prihlasenia' => $vsetky_prih));
    }

    public function actionConfirmation($id) {

        $model = $this->loadModel($id);

        $model->active = 1;
        $model->save();

        $gone = false;

        $headers = 'MIME-Version: 1.0' . "\r\n";
        $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";
        $headers .= 'From: ' . Yii::app()->params['adminEmail'] . "\r\n";
        $headers .= 'Reply-To: ' . Yii::app()->params['adminEmail'] . "\r\n";




        if (isset($_POST['regeneruj'])) {
            $md5Hash = md5(microtime());
            $mt = substr($md5Hash, 0, 8);
            $model->secure_hash = $mt;
            $model->password = hash('sha256', $mt);
            $model->active = 1;
            $model->passsent = 1;
            $model->save();

            $message_reg = '
    <html>
    <head>
       <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
       <title>email</title>
    </head>
    <body>
      Vážený pán/pani ' . $model->surname . '.<br />
      <br />           
      Ďakujeme Vám za prejavený záujem o naše služby. Nižšie uvádzame Vaše prihlasovacie údaje do Vášho účtu v našom systéme ' . $_SERVER['SERVER_NAME'] . '/admin . Tento účet okrem iného slúži na odhlasovanie z hodín v prípade Vašej neúčasti a nahlasovanie náhradných hodín. Prosíme Vás, aby ste si po prvom prihlásení zmenili heslo.<br />
      <br />
      <strong>Meno:</strong> ' . $model->email . '<br />
      <strong>Heslo:</strong> ' . $model->secure_hash . '<br />
      <br />
      <strong>V prípade každej neúčasti na cvičení, Vás prosíme o odhlásenie z hodiny na základe Vášich prihlasovacíh údajov - emailu a hesla. Systém nám tak umožní vami vzniknutý nárok na náhradnú hodinu evidovať a Vám si prehľadne nájsť miesto (náhradnú hodinu) za absenciu.</strong><br />
      <br />
      Odhlásiť sa z hodiny je možné vždy deň vopred do 18:00. Náhradnú hodinu si môžete vybrať z ponuky najbližších 7 dní. Počet náhradných hodín, na ktoré máte nárok uvidíte po prihlásení.<br />
      <br /> 
      Ďakujeme.<br />
      <br />
      S pozdravom
      Váš tím BigHugGym      
    </body>
    </html>      
    ';


            $gone = mail($model->email, 'Obnovené prihlasovacie údaje pre portál bighuggym', $message_reg, $headers);
            mail('kontrola.samorin@bighuggym.sk','ZALOHA: Obnovené prihlasovacie údaje pre portál bighuggym', "Heslo pre $model->email bolo uspesne zmenene.", $headers);
            if ($gone) {
                $gone = 'regen';
            }
        }


//return mail( $mod->email, "Prihlasovacie údaje do BigHugGym", $message);

        $this->render('confirmation', array('model' => $model, 'gone' => $gone));
    }

//------------------------------------------------------------------------------

    public function actionMassMail() {
        //posle email s telom vsetkym rodicom.


        if (isset($_POST['potvrdene'])) {
            $attrib = array("rights_ID" => $_POST['towhom']);

            if (isset($_POST['activeusers']) || isset($_POST['inactiveusers'])) {
                if ((isset($_POST['inactiveusers']) && ($_POST['inactiveusers'] == "include")) && ((isset($_POST['activeusers']) && ($_POST['activeusers'] == "include")))) {
                    
                } else {
                    if (isset($_POST['activeusers']) && ($_POST['activeusers'] == "include")) {
                        $attrib['active'] = 1;
                    }
                    if (isset($_POST['inactiveusers']) && ($_POST['inactiveusers'] == "include")) {
                        $attrib['active'] = 0;
                    }
                }
            }

            if (isset($_POST['subscribed']) || isset($_POST['notsubscribed'])) {
                if ((isset($_POST['subscribed']) && $_POST['subscribed'] == "include") && (isset($_POST['notsubscribed']) && $_POST['notsubscribed'] == "include")) {
                    
                } else {
                    if (isset($_POST['subscribed']) && $_POST['subscribed'] == "include") {
                        $attrib['subscribed'] = 1;
                    }
                    if (isset($_POST['notsubscribed']) && $_POST['notsubscribed'] == "include") {
                        $attrib['subscribed'] = 0;
                    }
                }
            }

            $data = Users::model()->findAllByAttributes($attrib);
            $value = false;

            $this->render('massmail', array('data' => $data, 'sent' => $value, 'attrib' => $attrib));
        } else

        if (isset($_POST['mailBody']) && (isset($_POST['mailSubj']))) {

            $attrib = json_decode($_POST['recipients']);

            $data = Users::model()->findAllByAttributes($attrib);

            $headers = 'MIME-Version: 1.0' . "\r\n";
            $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";
            $headers .= 'From: ' . Yii::app()->params['adminEmail'] . "\r\n";
            $headers .= 'Reply-To: ' . Yii::app()->params['adminEmail'] . "\r\n";

            //$headers .= 'BCC: ' . ' michal.pales@atlas.sk, pales.michael@gmail.com, jan@ptacin.com, info@bighuggym.com, ssasinkova@gmail.com,' . "\r\n";
//            $headers .= 'BCC: ' . ' pales.michael@gmail.com, jan@ptacin.com,' . "\r\n";

            $bcc = '';

            foreach ($data as $solo) {
                $bcc .= $solo->email . ', ';
            }

            $headers .= 'BCC: ' . $bcc . "\r\n";
            $value = mail(Yii::app()->params['adminEmail'], $_POST['mailSubj'], $_POST['mailBody'], $headers);
            //$value = mail('pales.michael@gmail.com', $_POST['mailSubj'], $_POST['mailBody'].$bcc, $headers);

            $this->render('mailprepare', array('sent' => $value));
        } else {

            $this->render('mailprepare', array('sent' => false));
        }
    }

//------------------------------------------------------------------------------    

    public function actionMassMailAlt() {
        //posle email s telom vsetkym rodicom.

        $meta = Metadata::model()->findAllByAttributes(array(
            'refTO' => 'dieta',
            'dataNAME' => 'pokracovanie',
            'data' => '1',
        ));
        
        $uzbolo = Metadata::model()->findAllByAttributes(array(
            'refTO' => 'dieta',
            'dataNAME' => 'rozvrh_zmeneny',
            'data' => '1',
        ));

        foreach ($meta as $key => $solo){ //odstranenie rodicov co uz zapisali deti
            $zmaz = FALSE;
            foreach ($uzbolo as $bol){
                if ($bol->refID == $solo->refID){
                    $zmaz = TRUE;
                }
            }
            if($zmaz){
                unset($meta[$key]);
            }
        }
        
        $pmails = array();
        foreach ($meta as $single) {
            $tkid = Kids::model()->with('parrent')->findByPk($single->refID);
            if (!(in_array($tkid->parrent->email, $pmails))) {
                $pmails[] = $tkid->parrent->email;
            }
        }

        $value = false;

        if (isset($_POST['mailBody']) && (isset($_POST['mailSubj']))) {

            $headers = 'MIME-Version: 1.0' . "\r\n";
            $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";
            $headers .= 'From: ' . Yii::app()->params['adminEmail'] . "\r\n";
            $headers .= 'Reply-To: ' . Yii::app()->params['adminEmail'] . "\r\n";
            //$headers .= 'BCC: '. 'jan@ptacin.com, info@bighuggym.com, michal.pales@atlas.sk, pales.michael@gmail.com, ssasinkova@gmail.com, '. "\r\n";  
            //$headers .= 'BCC: '. 'jan@ptacin.com, michal.pales@atlas.sk, pales.michael@gmail.com, '. "\r\n";  

            $bcc = '';

            foreach ($pmails as $solo) {
                $bcc .= $solo . ', ';
            }

            //$bcc .= 'michal.pales@gmail.com, jan@ptacin.com, ';
            $headers .= 'BCC: ' . $bcc . "\r\n";
            $value = mail(Yii::app()->params['adminEmail'], $_POST['mailSubj'], $_POST['mailBody'], $headers);
            //$value = mail('pales.michael@gmail.com', $_POST['mailSubj'], $_POST['mailBody'], $headers);
        }

        $this->render('massmailalt', array('data' => $pmails, 'sent' => $value));
    }

    /**
     * Performs the AJAX validation.
     * @param Users $model the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'users-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    public function actionDeactivateUsers() {
        //will lock all users with the rights of parent who do not have a active child with an enlist at the time.
        $parents = Users::model()->with(array('kids'))->findallByAttributes(array(
            'rights_ID' => '2',
            'active' => '1'
                ), array(
            'order' => 't.surname ASC'
        ));

        $werelocked = array();

        foreach ($parents as $one) {
            $lock = true;
            foreach ($one->kids as $kid) {
                $enlists = Enlist::model()->findAllByAttributes(array(
                    'ID_kid' => $kid->ID
                ));
                if (count($enlists) > 0) {
                    $lock = false;
                }
            }
            if ($lock) {
                $one->active = '0';
                //$one->save();
                $werelocked[] = $one;
            }
        }
        $this->render('lockusers', array('data' => $werelocked));
    }

    public function actionLockThem() {
        $deleted = array();
        if (isset($_POST['users'])) {
            //print_r($_POST);
            foreach ($_POST['users'] as $user) {
                $u = Users::model()->findByPk($user);
                $u->active = 0;
                $u->save();
                $deleted[] = $u->surname . ' ' . $u->name;
            }
        }
        //print_r($_POST);
        $this->render('locked', array('del' => $deleted));
    }
    
    public function actionViewProfile($id){
        //User with payments, Kid with test hours, + enlist
        $parent = Users::model()->findByPk($id);
        $kids = Kids::model()->with(array('enlists', 'payments'))->findAllByAttributes(array('parrent_ID'=>$id));
        foreach ($kids as $value) {
            $tryout[$value->ID] = Hours::model()->findAllByAttributes(array('ID_kids'=>$value->ID,'tryout'=>1));
        }
        $this->render('viewprofile', array('parent'=>$parent, 'kids'=>$kids, 'try'=>$tryout));
        
    }
}
