<?php

/**
 * This is the model class for table "enlist".
 *
 * The followings are the available columns in table 'enlist':
 * @property integer $ID
 * @property integer $ID_kid
 * @property integer $ID_timet
 * @property string $notes
 *
 * The followings are the available model relations:
 * @property Kids $iDK
 * @property Timetable $iDTimet
 * @property Hours[] $hours
 */
class Enlist extends CActiveRecord
{
    public $kid_name_search;
    public $kid_surname_search;
    public $day_s;
    public $time_start_s;
    public $lesson_s;
    
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'enlist';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('ID_kid, ID_timet', 'required'),
			array('ID_kid, ID_timet', 'numerical', 'integerOnly'=>true),
			array('notes', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('ID, ID_kid, ID_timet, notes, kid_name_search, kid_surname_search, time_start_s, day_s, lesson_s', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'iDK' => array(self::BELONGS_TO, 'Kids', 'ID_kid'),
			'iDTimet' => array(self::BELONGS_TO, 'Timetable', 'ID_timet'),
			'hours' => array(self::HAS_MANY, 'Hours', 'ID_enlist'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'ID' => 'ID',
			'ID_kid' => 'Id Kid',
			'ID_timet' => 'Id Timet',
			'notes' => 'Notes',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

                $criteria->with = array('iDK', 'iDTimet');
                
                $criteria->compare('iDK.name', $this->kid_name_search, true);
		$criteria->compare('iDK.surname', $this->kid_surname_search, true);
                
                $criteria->compare('iDTimet.week_day', $this->day_s, true);
                $criteria->compare('iDTimet.time_start', $this->time_start_s, true);
                $criteria->compare('iDTimet.lesson', $this->lesson_s, true);
                
                $criteria->compare('t.ID',$this->ID);
		$criteria->compare('t.ID_kid',$this->ID_kid);
		$criteria->compare('t.ID_timet',$this->ID_timet);
		$criteria->compare('t.notes',$this->notes,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
      'pagination'=>array(
        'pageSize'=>50,
      ),
    ));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Enlist the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
