<?php

/**
 * This is the model class for table "kids".
 *
 * The followings are the available columns in table 'kids':
 * @property integer $ID
 * @property integer $parrent_ID
 * @property string $name
 * @property string $surname
 * @property string $birthday
 * @property integer $active 
 * @property string $notes
 * @property string $tryout
 * @property string $frequency
 * @property string $lesson
 * @property integer $refund
 * @property string $label
 * @property string $dlgt1
 * @property string $dlgt2
 *
 * The followings are the available model relations:
 * @property Enlist[] $enlists
 * @property Users $parrent
 * @property Query[] $queries
 */
class Kids extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'kids';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('parrent_ID, name, surname, birthday, tryout, frequency, lesson', 'required'),
			array('parrent_ID, active, refund', 'numerical', 'integerOnly'=>true),
			array('name, surname, birthday, frequency, lesson', 'length', 'max'=>45),
			array('tryout', 'length', 'max'=>5),
			array('label', 'length', 'max'=>50),
			array('notes, dlgt1, dlgt2', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('ID, parrent_ID, name, surname, birthday, active, notes, tryout, frequency, lesson, refund, label, dlgt1, dlgt2', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'enlists' => array(self::HAS_MANY, 'Enlist', 'ID_kid'),
			'parrent' => array(self::BELONGS_TO, 'Users', 'parrent_ID'),
			'queries' => array(self::HAS_MANY, 'Query', 'kid_ID'),
      'payments' => array(self::HAS_MANY, 'Payments', 'ID_kid'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'ID' => 'ID',
			'parrent_ID' => 'Rodič',
			'name' => 'Meno',
			'surname' => 'Priezvisko',
			'birthday' => 'Dátum narodenia',
      'active' => 'Active',
			'notes' => 'Dôležté poznámky k dieťaťu/choroby/problémy',
			'tryout' => 'Absolvoval testovaciu hodinu?', 
			'frequency' => 'Frekvencia dochádzky týždenne',
			'lesson' => 'Trieda',
			'refund' => 'Počet nahraditelných hodín',
			'label' => 'Interná reprezentácia',
			'dlgt1' => 'Zakonný zástupca/Delegát 1',
			'dlgt2' => 'Zakonný zástupca/Delegát 2',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('ID',$this->ID);
		$criteria->compare('parrent_ID',$this->parrent_ID);
		$criteria->compare('name',$this->name,true);
		$criteria->compare('surname',$this->surname,true);
		$criteria->compare('birthday',$this->birthday,true);
		$criteria->compare('active',$this->active);
		$criteria->compare('notes',$this->notes,true);
		$criteria->compare('tryout',$this->tryout,true);
		$criteria->compare('frequency',$this->frequency,true);
		$criteria->compare('lesson',$this->lesson,true);
		$criteria->compare('refund',$this->refund);
		$criteria->compare('label',$this->label,true);
		$criteria->compare('dlgt1',$this->dlgt1,true);
		$criteria->compare('dlgt2',$this->dlgt2,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
      'pagination'=>array(
        'pageSize'=>50,
      ),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Kids the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
