<?php

/**
 * This is the model class for table "query".
 *
 * The followings are the available columns in table 'query':
 * @property integer $ID
 * @property integer $kid_ID
 * @property integer $timet_ID
 * @property string $timestamp
 * @property string $priority
 * @property string $notes
 *
 * The followings are the available model relations:
 * @property Kids $kid
 * @property Timetable $timet
 */
class Query extends CActiveRecord {

    public $lesson_name;
    public $lesson_hour;
    public $lesson_day;
    public $birthday;
    
    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'query';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('kid_ID, timet_ID', 'required'),
            array('kid_ID, timet_ID', 'numerical', 'integerOnly' => true),
            array('priority', 'length', 'max' => 1),
            array('notes', 'length', 'max' => 45),
            array('timestamp', 'safe'),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('ID, kid_ID, lesson_name, lesson_hour, lesson_day, timet_ID, timestamp, priority, notes, birthday', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'kid' => array(self::BELONGS_TO, 'Kids', 'kid_ID'),
            'timet' => array(self::BELONGS_TO, 'Timetable', 'timet_ID'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'ID' => 'ID',
            'kid_ID' => 'Kid',
            'timet_ID' => 'Timet',
            'timestamp' => 'Timestamp',
            'priority' => 'Priority',
            'notes' => 'Notes',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->with = array('timet', 'kid');

        $criteria->compare('timet.lesson', $this->lesson_name, true);
        $criteria->compare('timet.week_day', $this->lesson_day, true);
        $criteria->compare('timet.time_start', $this->lesson_hour, true);
        
        $criteria->compare('kid.birthday', $this->birthday, true);
        
        $criteria->compare('t.ID', $this->ID);
        $criteria->compare('t.kid_ID', $this->kid_ID);
        $criteria->compare('t.timet_ID', $this->timet_ID);
        $criteria->compare('t.timestamp', $this->timestamp, true);
        $criteria->compare('t.priority', $this->priority, true);
        $criteria->compare('t.notes', $this->notes, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'pagination' => array(
                'pageSize' => 50,
            ),
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Query the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
