<?php

/**
 * This is the model class for table "terms".
 *
 * The followings are the available columns in table 'terms':
 * @property integer $ID
 * @property string $timestamp
 * @property integer $parent_ID
 * @property integer $kid_ID
 * @property string $agreement_type
 * @property integer $agreement_value
 */
class Terms extends CActiveRecord
{
    public $parent_name;
    public $parent_surname;
    public $kid_name;
    public $kid_surname;
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'terms';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('parent_ID, kid_ID, agreement_type', 'required'),
			array('parent_ID, kid_ID, agreement_value', 'numerical', 'integerOnly'=>true),
			array('agreement_type', 'length', 'max'=>32),
			array('timestamp', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('ID, timestamp, parent_ID, kid_ID, agreement_type, agreement_value, parent_name, parent_surname, kid_name, kid_surname', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
                    'p_ID'=> array(self::BELONGS_TO, 'Users', 'parent_ID'),
                    'k_ID'=> array(self::BELONGS_TO, 'Kids', 'kid_ID'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'ID' => 'ID',
			'timestamp' => 'Timestamp',
			'parent_ID' => 'Parent',
			'kid_ID' => 'Kid',
			'agreement_type' => 'Agreement Type',
			'agreement_value' => 'Agreement Value',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

                $criteria->with = array('p_ID', 'k_ID');
                
                $criteria->compare('p_ID.name',$this->parent_name, true);
		$criteria->compare('p_ID.surname',$this->parent_surname, true);
                $criteria->compare('k_ID.name',$this->kid_name, true);
		$criteria->compare('k_ID.surname',$this->kid_surname, true);		
                
		$criteria->compare('t.ID',$this->ID);
		$criteria->compare('timestamp',$this->timestamp,true);
		$criteria->compare('parent_ID',$this->parent_ID);
		$criteria->compare('kid_ID',$this->kid_ID);
		$criteria->compare('LOWER(agreement_type)',strtolower($this->agreement_type),true);
		$criteria->compare('agreement_value',$this->agreement_value);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Terms the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
