<?php

/**
 * This is the model class for table "timetable".
 *
 * The followings are the available columns in table 'timetable':
 * @property integer $ID
 * @property integer $gym_ID
 * @property string $week_day
 * @property string $time_start
 * @property string $time_end
 * @property string $label
 * @property string $notes
 * @property integer $trainer
 * @property integer $trainer_alt
 * @property string $lesson
 * @property integer $active
 *
 * The followings are the available model relations:
 * @property Enlist[] $enlists
 * @property Query[] $queries
 * @property Users $trainer0
 * @property Gyms $gym
 */
class Timetable extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'timetable';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('gym_ID, week_day, time_start, time_end, trainer, lesson', 'required'),
			array('gym_ID, trainer, trainer_alt, active', 'numerical', 'integerOnly'=>true),
			array('week_day', 'length', 'max'=>15),
			array('label', 'length', 'max'=>50),
			array('lesson', 'length', 'max'=>45),
			array('notes', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('ID, gym_ID, week_day, time_start, time_end, label, notes, trainer, trainer_alt, lesson, active', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'enlists' => array(self::HAS_MANY, 'Enlist', 'ID_timet'),
			'queries' => array(self::HAS_MANY, 'Query', 'timet_ID'),
			'trainer0' => array(self::BELONGS_TO, 'Users', 'trainer'),
			'gym' => array(self::BELONGS_TO, 'Gyms', 'gym_ID'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'ID' => 'ID',
			'gym_ID' => 'Gym',
			'week_day' => 'Week Day',
			'time_start' => 'Time Start',
			'time_end' => 'Time End',
			'label' => 'Label',
			'notes' => 'Notes',
			'trainer' => 'Trainer',
			'trainer_alt' => 'Trainer Alt',
			'lesson' => 'Lesson',
                        'active' => 'Active',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('ID',$this->ID);
		$criteria->compare('gym_ID',$this->gym_ID);
		$criteria->compare('week_day',$this->week_day,true);
		$criteria->compare('time_start',$this->time_start,true);
		$criteria->compare('time_end',$this->time_end,true);
		$criteria->compare('label',$this->label,true);
		$criteria->compare('notes',$this->notes,true);
		$criteria->compare('trainer',$this->trainer);
		$criteria->compare('trainer_alt',$this->trainer_alt);
		$criteria->compare('lesson',$this->lesson,true);
		$criteria->compare('active',$this->active);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
      'pagination'=>array(
          'pageSize'=>50,
      ),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Timetable the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
